@@ -1,4 +1,4 @@
-from petrus._api import *  # main, run
+from petrus._core.api import *  # main, run
 from petrus.tests import *  # test
 
 if __name__ == "__main__":
