@@ -87,14 +87,16 @@ class Project(Calc):
         ans_ = self.prog.easy_list(ans_)
         return ans_
 
-    def _calc_description(self: Self) -> Any:
+    @cached_property
+    def description(self: Self) -> Any:
         if self.prog.kwargs["description"]:
             return self.prog.kwargs["description"]
         if self.get("description") is not None:
             return self.get("description")
         return self.name
 
-    def _calc_keywords(self: Self) -> Any:
+    @cached_property
+    def keywords(self: Self) -> Any:
         return self.get("keywords", default=[])
 
     def _calc_license(self: Self) -> Any:
